#  -*- coding: utf-8 -*-
# *****************************************************************************
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# Module authors:
#   Enrico Faulhaber <enrico.faulhaber@frm2.tum.de>
#
# *****************************************************************************
"""Define (internal) SECoP Errors"""


class SECOPError(RuntimeError):

    def __init__(self, *args, **kwds):
        RuntimeError.__init__(self)
        self.args = args
        for k, v in list(kwds.items()):
            setattr(self, k, v)

    def __repr__(self):
        args = ', '.join(map(repr, self.args))
        kwds = ', '.join(['%s=%r' % i for i in list(self.__dict__.items())])
        res = []
        if args:
            res.append(args)
        if kwds:
            res.append(kwds)
        return '%s(%s)' % (self.name, ', '.join(res))

    @property
    def name(self):
        return self.__class__.__name__[:-len('Error')]


class InternalError(SECOPError):
    name = 'InternalError'


class ProtocolError(SECOPError):
    name = 'SyntaxError'


class NoSuchModuleError(SECOPError):
    pass


class NoSuchParamError(SECOPError):
    pass


class NoSuchCommandError(SECOPError):
    pass


class ReadonlyError(SECOPError):
    pass


class BadValueError(SECOPError):
    pass


class CommandFailedError(SECOPError):
    pass


class CommandRunningError(SECOPError):
    pass


class CommunicationFailedError(SECOPError):
    pass


class IsBusyError(SECOPError):
    pass


class IsErrorError(SECOPError):
    pass


class DisabledError(SECOPError):
    pass



EXCEPTIONS = dict(
    NoSuchModule=NoSuchModuleError,
    NoSuchParam=NoSuchParamError,
    NoSuchCommand=NoSuchCommandError,
    CommandFailed=CommandFailedError,
    CommandRunning=CommandRunningError,
    Readonly=ReadonlyError,
    BadValue=BadValueError,
    CommunicationFailed=CommunicationFailedError,
    IsBusy=IsBusyError,
    IsError=IsErrorError,
    Disabled=DisabledError,
    SyntaxError=ProtocolError,
    InternalError=InternalError,
# internal short versions (candidates for spec)
    Protocol=ProtocolError,
    Internal=InternalError,
)
